# WatchDox
This repository provides functions to interact with the Blackberry WatchDox REST API

<img src="https://www.blackberry.com/content/dam/blackberry-com/media-gallery/images/blackberry-logo/BlackBerry_Logo_Black.png" alt="BlackBerry" width="200"/>


## What is BlackBerry Workspaces?
>BlackBerry® Workspaces is the leading secure EFSS solution, enabling users to share, edit and control their files on every device. Only BlackBerry Workspaces can provide the level of security organizations need — wherever files are, wherever they need to go, and whoever needs to access them.
[Workspaces Homepage](https://www.blackberry.com/us/en/products/blackberry-workspaces-efss)


## What is this repository for?
This repository contains updated production code that made it possible to interact with Watchdox Workspaces, Folders and User Permissions via the BlackBerry Workspaces REST API. This wrapper provides extensible functionality to create, delete and edit folders.

## Other Resources:
BlackBerry Workspaces REST API
[Workspaces REST API Reference Homepage](https://developers.blackberry.com/content/dam/developer-blackberry-com/api-reference/workspaces/workspaces-rest/index.html)
